# strange-loops

A system for focusing attention. Observations flow in, accumulate into state,
boundaries resolve, conclusions flow out. The conclusions re-enter as new
observations. The loop closes through the observer.

# Caveat
This is AI slop. It exists here because I was asked to share it, not because it is in a state to share and faffing about making it non-public seemed silly.